aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core/SkPath.h
diff options
context:
space:
mode:
authorGravatar Cary Clark <caryclark@skia.org>2018-06-14 13:21:08 -0400
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2018-06-14 18:02:37 +0000
commitca6a2454b8ebc191783cff1f47198d6c0ce8c2a8 (patch)
tree4f3379a83143d2cebcb95fa10404e2e316054d91 /include/core/SkPath.h
parentcf274da6faa9d32e08053180c8113fcaab666028 (diff)
refresh generated includes
Found some bookmaker bugs that were suppressing spelling errors and syntax errors. TBR=reed@google.com Bug: skia:6898 Change-Id: Ie7331dd03723d987cb2df46018a984f42d0ee518 Reviewed-on: https://skia-review.googlesource.com/134942 Reviewed-by: Cary Clark <caryclark@skia.org> Commit-Queue: Cary Clark <caryclark@skia.org> Auto-Submit: Cary Clark <caryclark@skia.org>
Diffstat (limited to 'include/core/SkPath.h')
-rw-r--r--include/core/SkPath.h98
1 files changed, 49 insertions, 49 deletions
diff --git a/include/core/SkPath.h b/include/core/SkPath.h
index 9906827ba8..85f22b5cab 100644
--- a/include/core/SkPath.h
+++ b/include/core/SkPath.h
@@ -6,7 +6,7 @@
*/
/* Generated by tools/bookmaker from include/core/SkPath.h and docs/SkPath_Reference.bmh
- on 2018-06-08 11:48:28. Additional documentation and examples can be found at:
+ on 2018-06-14 13:13:34. Additional documentation and examples can be found at:
https://skia.org/user/api/SkPath_Reference
You may edit either file directly. Structural changes to public interfaces require
@@ -29,7 +29,7 @@ class SkWStream;
/** \class SkPath
SkPath contain geometry. SkPath may be empty, or contain one or more verbs that
- outline a figure. SkPath always starts with a move verb to a Cartesian_Coordinate,
+ outline a figure. SkPath always starts with a move verb to a Cartesian coordinate,
and may be followed by additional verbs that add lines or curves.
Adding a close verb makes the geometry into a continuous loop, a closed contour.
SkPath may contain any number of contours, each beginning with a move verb.
@@ -476,7 +476,7 @@ public:
*/
void swap(SkPath& other);
/** Returns minimum and maximum x and y values of SkPoint array.
Returns (0, 0, 0, 0) if SkPath contains no points. Returned bounds width and height may
be larger or smaller than area affected when SkPath is drawn.
@@ -502,7 +502,7 @@ public:
this->getBounds();
}
/** Returns minimum and maximum x and y values of the lines and curves in SkPath.
Returns (0, 0, 0, 0) if SkPath contains no points.
Returned bounds width and height may be larger or smaller than area affected
when SkPath is drawn.
@@ -542,8 +542,8 @@ public:
/** Adds beginning of contour at SkPoint (x, y).
- @param x x-coordinate of contour start
- @param y y-coordinate of contour start
+ @param x x-axis value of contour start
+ @param y y-axis value of contour start
*/
void moveTo(SkScalar x, SkScalar y);
@@ -560,8 +560,8 @@ public:
Otherwise, start contour at last point offset by (dx, dy).
Function name stands for "relative move to".
- @param dx offset from last point x to contour start x
- @param dy offset from last point y to contour start y
+ @param dx offset from last point to contour start on x-axis
+ @param dy offset from last point to contour start on y-axis
*/
void rMoveTo(SkScalar dx, SkScalar dy);
@@ -596,8 +596,8 @@ public:
Line end is last point plus vector (dx, dy).
Function name stands for "relative line to".
- @param dx offset from last point x to line end x
- @param dy offset from last point y to line end y
+ @param dx offset from last point to line end on x-axis
+ @param dy offset from last point to line end on y-axis
*/
void rLineTo(SkScalar dx, SkScalar dy);
@@ -642,10 +642,10 @@ public:
Quad end is last point plus vector (dx2, dy2).
Function name stands for "relative quad to".
- @param dx1 offset from last point x to quad control x
- @param dy1 offset from last point x to quad control y
- @param dx2 offset from last point x to quad end x
- @param dy2 offset from last point x to quad end y
+ @param dx1 offset from last point to quad control on x-axis
+ @param dy1 offset from last point to quad control on y-axis
+ @param dx2 offset from last point to quad end on x-axis
+ @param dy2 offset from last point to quad end on y-axis
*/
void rQuadTo(SkScalar dx1, SkScalar dy1, SkScalar dx2, SkScalar dy2);
@@ -714,10 +714,10 @@ public:
Function name stands for "relative conic to".
- @param dx1 offset from last point x to conic control x
- @param dy1 offset from last point x to conic control y
- @param dx2 offset from last point x to conic end x
- @param dy2 offset from last point x to conic end y
+ @param dx1 offset from last point to conic control on x-axis
+ @param dy1 offset from last point to conic control on y-axis
+ @param dx2 offset from last point to conic end on x-axis
+ @param dy2 offset from last point to conic end on y-axis
@param w weight of added conic
*/
void rConicTo(SkScalar dx1, SkScalar dy1, SkScalar dx2, SkScalar dy2,
@@ -769,12 +769,12 @@ public:
Cubic end is last point plus vector (dx2, dy2).
Function name stands for "relative cubic to".
- @param x1 offset from last point x to first cubic control x
- @param y1 offset from last point x to first cubic control y
- @param x2 offset from last point x to second cubic control x
- @param y2 offset from last point x to second cubic control y
- @param x3 offset from last point x to cubic end x
- @param y3 offset from last point x to cubic end y
+ @param x1 offset from last point to first cubic control on x-axis
+ @param y1 offset from last point to first cubic control on y-axis
+ @param x2 offset from last point to second cubic control on x-axis
+ @param y2 offset from last point to second cubic control on y-axis
+ @param x3 offset from last point to cubic end on x-axis
+ @param y3 offset from last point to cubic end on y-axis
*/
void rCubicTo(SkScalar x1, SkScalar y1, SkScalar x2, SkScalar y2,
SkScalar x3, SkScalar y3);
@@ -800,10 +800,10 @@ public:
last SkPath point (x0, y0) to (x1, y1), and tangent from (x1, y1) to (x2, y2). Arc
is part of circle sized to radius, positioned so it touches both tangent lines.
- @param x1 x common to pair of tangents
- @param y1 y common to pair of tangents
- @param x2 x end of second tangent
- @param y2 y end of second tangent
+ @param x1 x-axis value common to pair of tangents
+ @param y1 y-axis value common to pair of tangents
+ @param x2 x-axis value end of second tangent
+ @param y2 y-axis value end of second tangent
@param radius distance from arc to circle center
*/
void arcTo(SkScalar x1, SkScalar y1, SkScalar x2, SkScalar y2, SkScalar radius);
@@ -879,7 +879,7 @@ public:
opposite the integer value of sweep; SVG "sweep-flag" uses 1 for clockwise, while
kCW_Direction cast to int is zero.
- @param r radii in x and y before x-axis rotation
+ @param r radii on axes before x-axis rotation
@param xAxisRotate x-axis rotation in degrees; positive values are clockwise
@param largeArc chooses smaller or larger arc
@param sweep chooses clockwise or counterclockwise arc
@@ -907,13 +907,13 @@ public:
opposite the integer value of sweep; SVG "sweep-flag" uses 1 for clockwise, while
kCW_Direction cast to int is zero.
- @param rx radius in x before x-axis rotation
- @param ry radius in y before x-axis rotation
+ @param rx radius before x-axis rotation
+ @param ry radius before x-axis rotation
@param xAxisRotate x-axis rotation in degrees; positive values are clockwise
@param largeArc chooses smaller or larger arc
@param sweep chooses clockwise or counterclockwise arc
- @param dx x offset end of arc from last SkPath SkPoint
- @param dy y offset end of arc from last SkPath SkPoint
+ @param dx x-axis offset end of arc from last SkPath SkPoint
+ @param dy y-axis offset end of arc from last SkPath SkPoint
*/
void rArcTo(SkScalar rx, SkScalar ry, SkScalar xAxisRotate, ArcSize largeArc,
Direction sweep, SkScalar dx, SkScalar dy);
@@ -1040,10 +1040,10 @@ public:
and bottom-left if dir is kCW_Direction; or followed by bottom-left,
bottom-right, and top-right if dir is kCCW_Direction.
- @param left smaller x of SkRect
- @param top smaller y of SkRect
- @param right larger x of SkRect
- @param bottom larger y of SkRect
+ @param left smaller x-axis value of SkRect
+ @param top smaller y-axis value of SkRect
+ @param right larger x-axis value of SkRect
+ @param bottom larger y-axis value of SkRect
@param dir SkPath::Direction to wind added contour
*/
void addRect(SkScalar left, SkScalar top, SkScalar right, SkScalar bottom,
@@ -1112,8 +1112,8 @@ public:
After appending, SkPath may be empty, or may contain: SkRect, oval, or RoundRect.
@param rect bounds of SkRRect
- @param rx x-radius of rounded corners on the SkRRect
- @param ry y-radius of rounded corners on the SkRRect
+ @param rx x-axis radius of rounded corners on the SkRRect
+ @param ry y-axis radius of rounded corners on the SkRRect
@param dir SkPath::Direction to wind SkRRect
*/
void addRoundRect(const SkRect& rect, SkScalar rx, SkScalar ry,
@@ -1182,8 +1182,8 @@ public:
verbs, SkPoint, and conic weights.
@param src SkPath verbs, SkPoint, and conic weights to add
- @param dx offset added to src SkPoint array x coordinates
- @param dy offset added to src SkPoint array y coordinates
+ @param dx offset added to src SkPoint array x-axis coordinates
+ @param dy offset added to src SkPoint array y-axis coordinates
@param mode kAppend_AddPathMode or kExtend_AddPathMode
*/
void addPath(const SkPath& src, SkScalar dx, SkScalar dy,
@@ -1227,16 +1227,16 @@ public:
/** Offset SkPoint array by (dx, dy). Offset SkPath replaces dst.
If dst is nullptr, SkPath is replaced by offset data.
- @param dx offset added to SkPoint array x coordinates
- @param dy offset added to SkPoint array y coordinates
+ @param dx offset added to SkPoint array x-axis coordinates
+ @param dy offset added to SkPoint array y-axis coordinates
@param dst overwritten, translated copy of SkPath; may be nullptr
*/
void offset(SkScalar dx, SkScalar dy, SkPath* dst) const;
/** Offset SkPoint array by (dx, dy). SkPath is replaced by offset data.
- @param dx offset added to SkPoint array x coordinates
- @param dy offset added to SkPoint array y coordinates
+ @param dx offset added to SkPoint array x-axis coordinates
+ @param dy offset added to SkPoint array y-axis coordinates
*/
void offset(SkScalar dx, SkScalar dy) {
this->offset(dx, dy, this);
@@ -1273,8 +1273,8 @@ public:
/** Set last point to (x, y). If SkPoint array is empty, append kMove_Verb to
verb array and append (x, y) to SkPoint array.
- @param x set x-coordinate of last point
- @param y set y-coordinate of last point
+ @param x set x-axis value of last point
+ @param y set y-axis value of last point
*/
void setLastPt(SkScalar x, SkScalar y);
@@ -1504,8 +1504,8 @@ public:
/** Returns true if the point (x, y) is contained by SkPath, taking into
account FillType.
- @param x x-coordinate of containment test
- @param y y-coordinate of containment test
+ @param x x-axis value of containment test
+ @param y y-axis value of containment test
@return true if SkPoint is in SkPath
*/
bool contains(SkScalar x, SkScalar y) const;
@@ -476,7 +476,7 @@ public:
*/
void swap(SkPath& other);
- /** Returns minimum and maximum x and y values of SkPoint array.
+ /** Returns minimum and maximum axes values of SkPoint array.
Returns (0, 0, 0, 0) if SkPath contains no points. Returned bounds width and height may
be larger or smaller than area affected when SkPath is drawn.
@@ -502,7 +502,7 @@ public:
this->getBounds();
}
- /** Returns minimum and maximum x and y values of the lines and curves in SkPath.
+ /** Returns minimum and maximum axes values of the lines and curves in SkPath.
Returns (0, 0, 0, 0) if SkPath contains no points.
Returned bounds width and height may be larger or smaller than area affected